function [Ad, Bd, Cd] = LinearizedMatrices(states,input, T)
% LINEARIZED MATRICES
%   The function returns linearized model of a vehicle.

% Initialize state variables
vx = states(1);
vy = states(2);
omega = states(3);

% Initialize input variables
deltaF = input(1);
sfl = input(2);
sfr = input(3);
srl = input(4);
srr = input(5);

% Limit vehicle longitudinal and lateral velocity values in order to 
% prevent division by 0
if (vx >= 0)
	vx = max(vx, 1e-6);
else
	vx = min(vx, -1e-6);
end

if (vy >= 0)
	vy = max(vy, 1e-6);
else
	vy = min(vy, -1e-6);
end

% Initialize matrices
nx = length(states);
nu = length(input);
A = zeros(nx,nx);
B = zeros(nx,nu);

% Define A matrix elements
% ROW 1
A(1,1) = (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - (cos(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) - (1023*vx^2)/(4375000*(vx^2 + vy^2)^(1/2)) - (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) + (cos(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (1023*(vx^2 + vy^2)^(1/2))/4375000;
A(1,2) = omega - (1023*vx*vy)/(4375000*(vx^2 + vy^2)^(1/2)) + (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - (sin(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) + (sin(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(1,3) = vy + (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 - (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - ((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))*((423*cos(deltaF))/500 + (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 + (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - ((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))*((423*cos(deltaF))/500 - (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(2,1) = (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) + (cos(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (25744*((131*omega)/100 - vy))/(875*(((423*omega)/500 + vx)^2 + ((131*omega)/100 - vy)^2)) - (25744*((131*omega)/100 - vy))/(875*(((423*omega)/500 - vx)^2 + ((131*omega)/100 - vy)^2)) - (1023*vx*vy)/(4375000*(vx^2 + vy^2)^(1/2)) - omega - (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - (cos(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(2,2) = (25744*((423*omega)/500 - vx))/(875*(((423*omega)/500 - vx)^2 + ((131*omega)/100 - vy)^2)) - (1023*(vx^2 + vy^2)^(1/2))/4375000 - (1023*vy^2)/(4375000*(vx^2 + vy^2)^(1/2)) - (25744*((423*omega)/500 + vx))/(875*(((423*omega)/500 + vx)^2 + ((131*omega)/100 - vy)^2)) - (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - (sin(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) + (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) + (sin(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(2,3) = (25744*(131/(100*((423*omega)/500 + vx)) - (423*((131*omega)/100 - vy))/(500*((423*omega)/500 + vx)^2))*((423*omega)/500 + vx)^2)/(875*(((423*omega)/500 + vx)^2 + ((131*omega)/100 - vy)^2)) - (25744*((423*omega)/500 - vx)^2*(131/(100*((423*omega)/500 - vx)) - (423*((131*omega)/100 - vy))/(500*((423*omega)/500 - vx)^2)))/(875*(((423*omega)/500 - vx)^2 + ((131*omega)/100 - vy)^2)) - vx - (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 - (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - ((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))*((423*cos(deltaF))/500 + (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) + (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 + (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - ((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))*((423*cos(deltaF))/500 - (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(3,1) = (1063043052578856605*((131*omega)/100 - vy))/(36028797018963968*(((423*omega)/500 + vx)^2 + ((131*omega)/100 - vy)^2)) + (1063043052578856605*((131*omega)/100 - vy))/(36028797018963968*(((423*omega)/500 - vx)^2 + ((131*omega)/100 - vy)^2)) + (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) + (cos(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(144115188075855872*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) + (cos(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(576460752303423488*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - (cos(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(144115188075855872*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) - (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(sin(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - (cos(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(576460752303423488*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(3,2) = (1063043052578856605*((423*omega)/500 + vx))/(36028797018963968*(((423*omega)/500 + vx)^2 + ((131*omega)/100 - vy)^2)) - (1063043052578856605*((423*omega)/500 - vx))/(36028797018963968*(((423*omega)/500 - vx)^2 + ((131*omega)/100 - vy)^2)) - (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - (sin(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(144115188075855872*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) + (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - (sin(deltaF)*(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx)))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(576460752303423488*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) + (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) + (sin(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(144115188075855872*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) + (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(cos(deltaF)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) + (sin(deltaF)*(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy)))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(576460752303423488*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));
A(3,3) = (1063043052578856605*((423*omega)/500 - vx)^2*(131/(100*((423*omega)/500 - vx)) - (423*((131*omega)/100 - vy))/(500*((423*omega)/500 - vx)^2)))/(36028797018963968*(((423*omega)/500 - vx)^2 + ((131*omega)/100 - vy)^2)) - (1063043052578856605*(131/(100*((423*omega)/500 + vx)) - (423*((131*omega)/100 - vy))/(500*((423*omega)/500 + vx)^2))*((423*omega)/500 + vx)^2)/(36028797018963968*(((423*omega)/500 + vx)^2 + ((131*omega)/100 - vy)^2)) - (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 - (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - ((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))*((423*cos(deltaF))/500 + (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(144115188075855872*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) + (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 - (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy)) - ((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))*((423*cos(deltaF))/500 + (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2))/(576460752303423488*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) + (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 + (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - ((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))*((423*cos(deltaF))/500 - (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(144115188075855872*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) + (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2*(((287*cos(deltaF))/200 + (423*sin(deltaF))/500)/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy)) - ((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))*((423*cos(deltaF))/500 - (287*sin(deltaF))/200))/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2))/(576460752303423488*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2));

% Define B matrix elements
% ROW 1
B(1,1) = (25744*atan2(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx), cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))*cos(deltaF))/875 - (43856*sfl*sin(deltaF))/875 - (43856*sfr*sin(deltaF))/875 + (25744*cos(deltaF)*atan2(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy), sin(deltaF)*((287*omega)/200 + vy) - cos(deltaF)*((423*omega)/500 - vx)))/875 - (25744*sin(deltaF)*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2 + 1)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) - (25744*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + 1))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2));
B(1,2) = (43856*cos(deltaF))/875;
B(1,3) = (43856*cos(deltaF))/875;
B(1,4) = 43856/875;
B(1,5) = 43856/875;
B(2,1) = (25744*atan2(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy), sin(deltaF)*((287*omega)/200 + vy) - cos(deltaF)*((423*omega)/500 - vx))*sin(deltaF))/875 + (25744*atan2(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx), cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))*sin(deltaF))/875 + (43856*sfl*cos(deltaF))/875 + (43856*sfr*cos(deltaF))/875 + (25744*cos(deltaF)*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2 + 1)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)/(875*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) + (25744*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + 1))/(875*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2));
B(2,2) = (43856*sin(deltaF))/875;
B(2,3) = (43856*sin(deltaF))/875;
B(2,4) = 0;
B(2,5) = 0;
B(3,1) = (4657913833437126837*atan2(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy), sin(deltaF)*((287*omega)/200 + vy) - cos(deltaF)*((423*omega)/500 - vx))*sin(deltaF))/144115188075855872 + (10984237221150688273*atan2(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx), cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))*cos(deltaF))/576460752303423488 + (4657913833437126837*atan2(cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx), cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))*sin(deltaF))/144115188075855872 + (7934954516750257713*sfl*cos(deltaF))/144115188075855872 + (7934954516750257713*sfr*cos(deltaF))/144115188075855872 + (18712115738454963677*sfl*sin(deltaF))/576460752303423488 - (18712115738454963677*sfr*sin(deltaF))/576460752303423488 - (10984237221150688273*cos(deltaF)*atan2(sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy), sin(deltaF)*((287*omega)/200 + vy) - cos(deltaF)*((423*omega)/500 - vx)))/576460752303423488 + (4657913833437126837*cos(deltaF)*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2 + 1)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)/(144115188075855872*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) + (10984237221150688273*sin(deltaF)*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2/(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2 + 1)*(cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)/(576460752303423488*((sin(deltaF)*((423*omega)/500 - vx) + cos(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((423*omega)/500 - vx) - sin(deltaF)*((287*omega)/200 + vy))^2)) + (4657913833437126837*cos(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + 1))/(144115188075855872*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2)) - (10984237221150688273*sin(deltaF)*(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2*((cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2/(cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + 1))/(576460752303423488*((cos(deltaF)*((423*omega)/500 + vx) + sin(deltaF)*((287*omega)/200 + vy))^2 + (cos(deltaF)*((287*omega)/200 + vy) - sin(deltaF)*((423*omega)/500 + vx))^2));
B(3,2) = (7934954516750257713*sin(deltaF))/144115188075855872 - (18712115738454963677*cos(deltaF))/576460752303423488;
B(3,3) = (18712115738454963677*cos(deltaF))/576460752303423488 + (7934954516750257713*sin(deltaF))/144115188075855872;
B(3,4) = -18712115738454963677/576460752303423488;
B(3,5) = 18712115738454963677/576460752303423488;

% Create discrete system
sysCont = ss(A, B, eye(nx), zeros(nx,nu));
sysDisc = c2d(sysCont, T, 'tustin');
Ad = sysDisc.A;
Bd = sysDisc.B;
Cd = [1 0 0;
      0 0 1];

end